import {
  loadPackage
} from "./chunk-SZROR4OA.js";

// src/loader/fileLoader.ts
import { basename, dirname } from "path";
var parseToml;
var cosmiconfig;
var loadToml = function loadToml2(filepath, content) {
  parseToml = loadPackage(
    "@iarna/toml",
    "fileLoader's ability to parse TOML files"
  ).parse;
  try {
    const result = parseToml(content);
    return result;
  } catch (error) {
    error.message = `TOML Error in ${filepath}:
${error.message}`;
    throw error;
  }
};
var getSearchOptions = (options) => {
  if (options.absolutePath) {
    return {
      searchPlaces: [basename(options.absolutePath)],
      searchFrom: dirname(options.absolutePath)
    };
  }
  const { basename: name = ".env", loaders = {} } = options;
  const additionalFormats = Object.keys(loaders).map((ext) => ext.slice(1));
  const formats = [...additionalFormats, "toml", "yaml", "yml", "json", "js"];
  return {
    searchPlaces: [
      ...formats.map((format) => `${name}.${process.env.NODE_ENV}.${format}`),
      ...formats.map((format) => `${name}.${format}`)
    ],
    searchFrom: options.searchFrom
  };
};
var placeholderResolver = (template, data, disallowUndefinedEnvironmentVariables) => {
  const replace = (placeholder, key) => {
    let value = data;
    for (const property of key.split("."))
      value = value[property];
    if (!value && disallowUndefinedEnvironmentVariables) {
      throw new Error(
        `Environment variable is not set for variable name: '${key}'`
      );
    }
    return String(value);
  };
  const braceRegex = /\${(\d+|[a-z$_][\w\-$]*?(?:\.[\w\-$]*?)*?)}/gi;
  return template.replace(braceRegex, replace);
};
var fileLoader = (options = {}) => {
  cosmiconfig = loadPackage("cosmiconfig", "fileLoader");
  const { cosmiconfigSync } = cosmiconfig;
  return () => {
    const { searchPlaces, searchFrom } = getSearchOptions(options);
    const loaders = {
      ".toml": loadToml,
      ...options.loaders
    };
    const explorer = cosmiconfigSync("env", {
      searchPlaces,
      ...options,
      loaders
    });
    const result = explorer.search(searchFrom);
    if (!result)
      throw new Error("Failed to find configuration file.");
    let config = result.config;
    if (!(options.ignoreEnvironmentVariableSubstitution ?? true)) {
      const replacedConfig = placeholderResolver(
        JSON.stringify(result.config),
        process.env,
        options.disallowUndefinedEnvironmentVariables ?? true
      );
      config = JSON.parse(replacedConfig);
    }
    return config;
  };
};

export {
  fileLoader
};
