import {
  fileLoader
} from "./chunk-BSMHZZTG.js";
import "./chunk-SZROR4OA.js";

// src/index.ts
import merge from "lodash.merge";
import chalk from "chalk";
import { plainToClass } from "class-transformer";
import { validateSync } from "class-validator";
var { blue, red, cyan, yellow } = chalk;
var TypedConfig = class {
  async init(options) {
    const rawConfig = await this.getRawConfigAsync(options.load);
    return this.processConfig(options, rawConfig);
  }
  async processConfig(options, rawConfig) {
    const {
      schema: Config,
      validationOptions,
      normalize = (config2) => config2,
      validate = this.validateWithClassValidator.bind(this)
    } = options;
    if (typeof rawConfig !== "object") {
      throw new TypeError(
        `Configuration should be an object, received: ${rawConfig}. Please check the return value of \`load()\``
      );
    }
    const normalized = normalize(rawConfig);
    const config = validate(normalized, Config, validationOptions);
    return config;
  }
  async getRawConfigAsync(load) {
    if (Array.isArray(load)) {
      const config = {};
      for (const fn of load) {
        try {
          const conf = await fn();
          merge(config, conf);
        } catch (err) {
          console.log(`Config load failed: ${err.message}`);
        }
      }
      return config;
    }
    return load();
  }
  validateWithClassValidator(rawConfig, Config, options) {
    const config = plainToClass(Config, rawConfig, {
      exposeDefaultValues: true
    });
    const schemaErrors = validateSync(config, {
      forbidUnknownValues: true,
      whitelist: true,
      ...options
    });
    if (schemaErrors.length > 0) {
      const configErrorMessage = this.getConfigErrorMessage(schemaErrors);
      throw new Error(configErrorMessage);
    }
    return config;
  }
  getConfigErrorMessage(errors) {
    const messages = this.formatValidationError(errors).map(({ property, value, constraints }) => {
      const constraintMessage = Object.entries(
        constraints || {}
      ).map(
        ([key, val]) => `    - ${key}: ${yellow(val)}, current config is \`${blue(
          JSON.stringify(value)
        )}\``
      ).join("\n");
      const msg = [
        `  - config ${cyan(property)} does not match the following rules:`,
        `${constraintMessage}`
      ].join("\n");
      return msg;
    }).filter(Boolean).join("\n");
    const configErrorMessage = red(
      `Configuration is not valid:
${messages}
`
    );
    return configErrorMessage;
  }
  formatValidationError(errors) {
    const result = [];
    const helper = ({ property, constraints, children, value }, prefix) => {
      const keyPath = prefix ? `${prefix}.${property}` : property;
      if (constraints) {
        result.push({
          property: keyPath,
          constraints,
          value
        });
      }
      if (children && children.length)
        children.forEach((child) => helper(child, keyPath));
    };
    errors.forEach((error) => helper(error, ""));
    return result;
  }
};
async function defineConfig(options) {
  const typedConfigTarget = new TypedConfig();
  const typedConfig = await typedConfigTarget.init(options);
  return typedConfig;
}
export {
  TypedConfig,
  defineConfig,
  fileLoader
};
